@@ -53,29 +53,34 @@
  *      written permission.
  */
 
-#ifndef _MD5_H__
-#define _MD5_H__
+#ifndef OPENIPMI_MD5_H__
+#define OPENIPMI_MD5_H__
 
 #include <OpenIPMI/ipmi_auth.h>
 
+IPMI_UTILS_DLL_PUBLIC
 int ipmi_md5_authcode_init(unsigned char   *password, 
 			   ipmi_authdata_t *handle,
 			   void            *info,
 			   void            *(*mem_alloc)(void *info, int size),
 			   void            (*mem_free)(void *info, void *data));
 /* Allow variable-length passwords. */
+IPMI_UTILS_DLL_PUBLIC
 int ipmi_md5_authcode_initl(const unsigned char *password, 
 			    unsigned int        password_len,
 			    ipmi_authdata_t     *handle,
 			    void                *info,
 			    void                *(*mem_alloc)(void *info, int size),
 			    void                (*mem_free)(void *info, void *data));
+IPMI_UTILS_DLL_PUBLIC
 int ipmi_md5_authcode_gen(ipmi_authdata_t handle,
 			  ipmi_auth_sg_t  data[],
 			  void            *output);
+IPMI_UTILS_DLL_PUBLIC
 int ipmi_md5_authcode_check(ipmi_authdata_t handle,
 			    ipmi_auth_sg_t  data[],
 			    void            *code);
+IPMI_UTILS_DLL_PUBLIC
 void ipmi_md5_authcode_cleanup(ipmi_authdata_t handle);
 
-#endif /* _MD5_H__ */
+#endif /* OPENIPMI_MD5_H__ */
