@@ -31,11 +31,16 @@
  *  Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  */
 
-#ifndef __IPMI_SMI_H
-#define __IPMI_SMI_H
+#ifndef OPENIPMI_SMI_H
+#define OPENIPMI_SMI_H
 
+#include <OpenIPMI/dllvisibility.h>
 #include <OpenIPMI/ipmi_mc.h>
+#ifdef _WIN32
+#include <winsock2.h>
+#else
 #include <netinet/in.h>
+#endif
 
 #ifdef __cplusplus
 extern "C" {
@@ -50,6 +55,7 @@ extern "C" {
  *     user.  The user can use it for anything they like.
  *  new_con - the newly created connection is returned here.
  */
+IPMI_DLL_PUBLIC
 int ipmi_smi_setup_con(int                if_num,
 		       os_handler_t       *handlers,
 		       void               *user_data,
@@ -59,4 +65,4 @@ int ipmi_smi_setup_con(int                if_num,
 }
 #endif
 
-#endif /* __IPMI_SMI_H */
+#endif /* OPENIPMI_SMI_H */
