@@ -1006,7 +1006,8 @@ vm_connected(serserv_data_t *si)
     c[len++] = VM_CMD_CHAR;
     raw_send(si, c, len);
     si->connected = 1;
-    ipmi_resend_atn(&si->channel);
+    if (si->sysinfo->resend_atn)
+	si->sysinfo->resend_atn(&si->channel);
 }
 
 static void
