@@ -57,13 +57,6 @@
 
 #include <OpenIPMI/internal/ipmi_int.h>
 
-/* CHEAP HACK - we don't want the user to have to provide this any
-   more. */
-extern void posix_vlog(char                 *format,
-		       enum ipmi_log_type_e log_type,
-		       va_list              ap);
-#pragma weak posix_vlog
-
 static void i_posix_lock(pthread_mutex_t *lock)
 {
     int rv = pthread_mutex_lock(lock);
@@ -147,8 +140,6 @@ add_fd(os_handler_t       *handler,
     fd_data->data_ready = data_ready;
     fd_data->handler = handler;
     fd_data->freed = freed;
-    sel_set_fd_write_handler(posix_sel, fd, SEL_FD_HANDLER_DISABLED);
-    sel_set_fd_except_handler(posix_sel, fd, SEL_FD_HANDLER_DISABLED);
     rv = sel_set_fd_handlers(posix_sel, fd, fd_data, fd_handler, NULL, NULL,
 			     free_fd_data);
     if (rv) {
@@ -386,8 +377,6 @@ sposix_vlog(os_handler_t         *handler,
 
     if (log_handler)
 	log_handler(handler, format, log_type, ap);
-    else if (posix_vlog)
-	posix_vlog((char *) format, log_type, ap);
     else
 	default_vlog(format, log_type, ap);
 }
@@ -675,6 +664,8 @@ perform_one_op(os_handler_t   *os_hnd,
 		    timeout);
     if (rv == -1)
 	return errno;
+    if (rv == 0)
+	return ETIMEDOUT;
     return 0;
 }
 
