@@ -49,7 +49,13 @@
 #include <stdlib.h>
 #include <errno.h>
 #include <stdio.h>
+#ifdef _WIN32
+#include <winsock2.h>
+static void syslog(int level, char *format, ...) {}
+#define LOG_ERR 3
+#else
 #include <syslog.h>
+#endif
 #include <signal.h>
 #include <string.h>
 #include <assert.h>
@@ -87,11 +93,25 @@ typedef struct fd_control_s
        whether the FD has been deleted and information to handle the
        deletion. */
     fd_state_t       *state;
-    void             *data;		/* Operation-specific data */
+
+    /* Link in the hash list. */
+    struct fd_control_s *next;
+
+    /* Handlers for various events on an fd. */
+    void             *data; /* Passed to the handlers */
     sel_fd_handler_t handle_read;
     sel_fd_handler_t handle_write;
     sel_fd_handler_t handle_except;
+
+    int fd;
+
+    /* Keep track of whether the event is enabled here. */
+    char read_enabled;
+    char write_enabled;
+    char except_enabled;
+
 #ifdef HAVE_EPOLL_PWAIT
+    /* See the comment in process_fds_epoll() on the use of this. */
     uint32_t saved_events;
 #endif
 } fd_control_t;
@@ -178,19 +198,8 @@ typedef struct sel_wait_list_s
 
 struct selector_s
 {
-    /* This is an array of all the file descriptors possible.  This is
-       moderately wasteful of space, but easy to do.  Hey, memory is
-       cheap. */
-    volatile fd_control_t fds[FD_SETSIZE];
-    
-    /* These are the offical fd_sets used to track what file descriptors
-       need to be monitored. */
-    volatile fd_set read_set;
-    volatile fd_set write_set;
-    volatile fd_set except_set;
-
-    volatile int maxfd; /* The largest file descriptor registered with
-			   this code. */
+    /* This is an hash table of file descriptors. */
+    fd_control_t *fds[FD_SETSIZE];
 
     /* If something is deleted, we increment this count.  This way when
        a select/epoll returns a non-timeout, we know that we need to ignore
@@ -220,6 +229,17 @@ struct selector_s
     void (*sel_lock_free)(sel_lock_t *);
     void (*sel_lock)(sel_lock_t *);
     void (*sel_unlock)(sel_lock_t *);
+
+    /* Everything below is only used for select() and ignore for epoll. */
+
+    /* These are the offical fd_sets used to track what file descriptors
+       need to be monitored. */
+    volatile fd_set read_set;
+    volatile fd_set write_set;
+    volatile fd_set except_set;
+
+    volatile int maxfd; /* The largest file descriptor registered with
+			   this code. */
 };
 
 static void
@@ -324,13 +344,15 @@ init_fd(fd_control_t *fd)
     fd->handle_read = NULL;
     fd->handle_write = NULL;
     fd->handle_except = NULL;
+    fd->read_enabled = 0;
+    fd->write_enabled = 0;
+    fd->except_enabled = 0;
 }
 
 #ifdef HAVE_EPOLL_PWAIT
 static int
-sel_update_fd(struct selector_s *sel, int fd, int op)
+sel_update_fd(struct selector_s *sel, fd_control_t *fdc, int op)
 {
-    fd_control_t *fdc = (fd_control_t *) &sel->fds[fd];
     struct epoll_event event;
     int rv;
 
@@ -339,29 +361,29 @@ sel_update_fd(struct selector_s *sel, int fd, int op)
 
     memset(&event, 0, sizeof(event));
     event.events = EPOLLONESHOT;
-    event.data.fd = fd;
+    event.data.fd = fdc->fd;
     if (fdc->saved_events) {
 	if (op == EPOLL_CTL_DEL)
 	    return 0;
-	if (!FD_ISSET(fd, &sel->read_set) && !FD_ISSET(fd, &sel->except_set))
+	if (!fdc->read_enabled && !fdc->except_enabled)
 	    return 0;
 	fdc->saved_events = 0;
 	op = EPOLL_CTL_ADD;
-	if (FD_ISSET(fd, &sel->read_set))
+	if (fdc->read_enabled)
 	    event.events |= EPOLLIN | EPOLLHUP;
-	if (FD_ISSET(fd, &sel->except_set))
+	if (fdc->except_enabled)
 	    event.events |= EPOLLERR | EPOLLPRI;
     } else if (op != EPOLL_CTL_DEL) {
-	if (FD_ISSET(fd, &sel->read_set))
+	if (fdc->read_enabled)
 	    event.events |= EPOLLIN | EPOLLHUP;
-	if (FD_ISSET(fd, &sel->write_set))
+	if (fdc->write_enabled)
 	    event.events |= EPOLLOUT;
-	if (FD_ISSET(fd, &sel->except_set))
+	if (fdc->except_enabled)
 	    event.events |= EPOLLERR | EPOLLPRI;
     }
     /* This should only fail due to system problems, and if that's the case,
        well, we should probably terminate. */
-    rv = epoll_ctl(sel->epollfd, op, fd, &event);
+    rv = epoll_ctl(sel->epollfd, op, fdc->fd, &event);
     if (rv) {
 	perror("epoll_ctl");
 	assert(0);
@@ -370,7 +392,7 @@ sel_update_fd(struct selector_s *sel, int fd, int op)
 }
 #else
 static int
-sel_update_fd(struct selector_s *sel, int fd, int op)
+sel_update_fd(struct selector_s *sel, fd_control_t *fdc, int op)
 {
     return 1;
 }
@@ -386,6 +408,28 @@ finish_oldstate(sel_runner_t *runner, void *cbdata)
     free(oldstate);
 }
 
+/* Must be called with sel fd lock held. */
+static fd_control_t *
+get_fd(struct selector_s *sel, int fd)
+{
+    fd_control_t *fdc = sel->fds[fd % FD_SETSIZE];
+
+    while (fdc && fdc->fd != fd)
+	fdc = fdc->next;
+    return fdc;
+}
+
+static void
+valid_fd(struct selector_s *sel, int fd, fd_control_t **rfdc)
+{
+    fd_control_t *fdc;
+
+    assert(fd >= 0);
+    fdc = get_fd(sel, fd);
+    assert(fdc != NULL);
+    *rfdc = fdc;
+}
+
 /* Set the handlers for a file descriptor. */
 int
 sel_set_fd_handlers(struct selector_s *sel,
@@ -401,6 +445,11 @@ sel_set_fd_handlers(struct selector_s *sel,
     void         *olddata = NULL;
     int          added = 1;
 
+#ifdef HAVE_EPOLL_PWAIT
+    if (sel->epollfd < 0 && fd >= FD_SETSIZE)
+	return EMFILE;
+#endif
+
     state = malloc(sizeof(*state));
     if (!state)
 	return ENOMEM;
@@ -410,7 +459,21 @@ sel_set_fd_handlers(struct selector_s *sel,
     state->done_runner.sel = sel;
 
     sel_fd_lock(sel);
-    fdc = (fd_control_t *) &(sel->fds[fd]);
+    fdc = get_fd(sel, fd);
+    if (!fdc) {
+	fdc = malloc(sizeof(*fdc));
+	if (!fdc) {
+	    sel_fd_unlock(sel);
+	    free(state);
+	    return ENOMEM;
+	}
+	memset(fdc, 0, sizeof(*fdc));
+	fdc->fd = fd;
+	/* Add it to the list. */
+	fdc->next = sel->fds[fd % FD_SETSIZE];
+	sel->fds[fd % FD_SETSIZE] = fdc;
+    }
+
     if (fdc->state) {
 	oldstate = fdc->state;
 	olddata = fdc->data;
@@ -428,14 +491,13 @@ sel_set_fd_handlers(struct selector_s *sel,
 
     if (added) {
 	/* Move maxfd up if necessary. */
-	if (fd > sel->maxfd) {
+	if (fd > sel->maxfd)
 	    sel->maxfd = fd;
-	}
 
-	if (sel_update_fd(sel, fd, EPOLL_CTL_ADD))
+	if (sel_update_fd(sel, fdc, EPOLL_CTL_ADD))
 	    sel_wake_all(sel);
     } else {
-	if (sel_update_fd(sel, fd, EPOLL_CTL_MOD))
+	if (sel_update_fd(sel, fdc, EPOLL_CTL_MOD))
 	    sel_wake_all(sel);
     }
     sel_fd_unlock(sel);
@@ -459,14 +521,14 @@ i_sel_clear_fd_handler(struct selector_s *sel, int fd, int imm)
     void         *olddata = NULL;
 
     sel_fd_lock(sel);
-    fdc = (fd_control_t *) &(sel->fds[fd]);
+    valid_fd(sel, fd, &fdc);
 
     if (fdc->state) {
 	oldstate = fdc->state;
 	olddata = fdc->data;
 	fdc->state = NULL;
 
-	sel_update_fd(sel, fd, EPOLL_CTL_DEL);
+	sel_update_fd(sel, fdc, EPOLL_CTL_DEL);
 #ifdef HAVE_EPOLL_PWAIT
 	fdc->saved_events = 0;
 #endif
@@ -474,15 +536,20 @@ i_sel_clear_fd_handler(struct selector_s *sel, int fd, int imm)
     }
 
     init_fd(fdc);
-    FD_CLR(fd, &sel->read_set);
-    FD_CLR(fd, &sel->write_set);
-    FD_CLR(fd, &sel->except_set);
+#ifdef HAVE_EPOLL_PWAIT
+    if (sel->epollfd < 0)
+#endif
+    {
+	FD_CLR(fd, &sel->read_set);
+	FD_CLR(fd, &sel->write_set);
+	FD_CLR(fd, &sel->except_set);
+    }
 
     /* Move maxfd down if necessary. */
     if (fd == sel->maxfd) {
-	while ((sel->maxfd >= 0) && (! sel->fds[sel->maxfd].state)) {
+	while (sel->maxfd >= 0 && (!sel->fds[sel->maxfd] ||
+				   !sel->fds[sel->maxfd]->state))
 	    sel->maxfd--;
-	}
     }
 
     sel_fd_unlock(sel);
@@ -522,22 +589,32 @@ sel_clear_fd_handlers_imm(struct selector_s *sel, int fd)
 void
 sel_set_fd_read_handler(struct selector_s *sel, int fd, int state)
 {
-    fd_control_t *fdc = (fd_control_t *) &(sel->fds[fd]);
+    fd_control_t *fdc;
 
     sel_fd_lock(sel);
+    valid_fd(sel, fd, &fdc);
+
     if (!fdc->state)
 	goto out;
 
     if (state == SEL_FD_HANDLER_ENABLED) {
-	if (FD_ISSET(fd, &sel->read_set))
+	if (fdc->read_enabled)
 	    goto out;
-	FD_SET(fd, &sel->read_set);
+	fdc->read_enabled = 1;
+#ifdef HAVE_EPOLL_PWAIT
+	if (sel->epollfd < 0)
+#endif
+	    FD_SET(fd, &sel->read_set);
     } else if (state == SEL_FD_HANDLER_DISABLED) {
-	if (!FD_ISSET(fd, &sel->read_set))
+	if (!fdc->read_enabled)
 	    goto out;
-	FD_CLR(fd, &sel->read_set);
+	fdc->read_enabled = 0;
+#ifdef HAVE_EPOLL_PWAIT
+	if (sel->epollfd < 0)
+#endif
+	    FD_CLR(fd, &sel->read_set);
     }
-    if (sel_update_fd(sel, fd, EPOLL_CTL_MOD))
+    if (sel_update_fd(sel, fdc, EPOLL_CTL_MOD))
 	sel_wake_all(sel);
 
  out:
@@ -549,22 +626,32 @@ sel_set_fd_read_handler(struct selector_s *sel, int fd, int state)
 void
 sel_set_fd_write_handler(struct selector_s *sel, int fd, int state)
 {
-    fd_control_t *fdc = (fd_control_t *) &(sel->fds[fd]);
+    fd_control_t *fdc;
 
     sel_fd_lock(sel);
+    valid_fd(sel, fd, &fdc);
+
     if (!fdc->state)
 	goto out;
 
     if (state == SEL_FD_HANDLER_ENABLED) {
-	if (FD_ISSET(fd, &sel->write_set))
+	if (fdc->write_enabled)
 	    goto out;
-	FD_SET(fd, &sel->write_set);
+	fdc->write_enabled = 1;
+#ifdef HAVE_EPOLL_PWAIT
+	if (sel->epollfd < 0)
+#endif
+	    FD_SET(fd, &sel->write_set);
     } else if (state == SEL_FD_HANDLER_DISABLED) {
-	if (!FD_ISSET(fd, &sel->write_set))
+	if (!fdc->write_enabled)
 	    goto out;
-	FD_CLR(fd, &sel->write_set);
+	fdc->write_enabled = 0;
+#ifdef HAVE_EPOLL_PWAIT
+	if (sel->epollfd < 0)
+#endif
+	    FD_CLR(fd, &sel->write_set);
     }
-    if (sel_update_fd(sel, fd, EPOLL_CTL_MOD))
+    if (sel_update_fd(sel, fdc, EPOLL_CTL_MOD))
 	sel_wake_all(sel);
 
  out:
@@ -576,22 +663,32 @@ sel_set_fd_write_handler(struct selector_s *sel, int fd, int state)
 void
 sel_set_fd_except_handler(struct selector_s *sel, int fd, int state)
 {
-    fd_control_t *fdc = (fd_control_t *) &(sel->fds[fd]);
+    fd_control_t *fdc;
 
     sel_fd_lock(sel);
+    valid_fd(sel, fd, &fdc);
+
     if (!fdc->state)
 	goto out;
 
     if (state == SEL_FD_HANDLER_ENABLED) {
-	if (FD_ISSET(fd, &sel->except_set))
+	if (fdc->except_enabled)
 	    goto out;
-	FD_SET(fd, &sel->except_set);
+	fdc->except_enabled = 1;
+#ifdef HAVE_EPOLL_PWAIT
+	if (sel->epollfd < 0)
+#endif
+	    FD_SET(fd, &sel->except_set);
     } else if (state == SEL_FD_HANDLER_DISABLED) {
-	if (!FD_ISSET(fd, &sel->except_set))
+	if (!fdc->except_enabled)
 	    goto out;
-	FD_CLR(fd, &sel->except_set);
+	fdc->except_enabled = 0;
+#ifdef HAVE_EPOLL_PWAIT
+	if (sel->epollfd < 0)
+#endif
+	    FD_CLR(fd, &sel->except_set);
     }
-    if (sel_update_fd(sel, fd, EPOLL_CTL_MOD))
+    if (sel_update_fd(sel, fdc, EPOLL_CTL_MOD))
 	sel_wake_all(sel);
 
  out:
@@ -744,27 +841,23 @@ sel_stop_timer_with_done(sel_timer_t *timer,
 			 void *cb_data)
 {
     struct selector_s *sel = timer->val.sel;
+    int rv = EBUSY;
 
     sel_timer_lock(sel);
-    if (timer->val.done_handler) {
-	sel_timer_unlock(sel);
-	return EBUSY;
-    }
-    if (timer->val.stopped) {
-	sel_timer_unlock(sel);
-	return ETIMEDOUT;
-    }
+    if (timer->val.done_handler)
+	goto out_unlock;
+    rv = ETIMEDOUT;
+    if (timer->val.stopped || timer->val.in_handler)
+	goto out_unlock;
 
+    rv = 0;
     timer->val.stopped = 1;
 
     timer->val.done_handler = done_handler;
     timer->val.done_cb_data = cb_data;
 
-    if (timer->val.in_handler)
-	goto out_unlock;
-
     /*
-     * We don't want to run the done handler here do avoid locking
+     * We don't want to run the done handler here to avoid locking
      * issues.  So set it in_handler and stick it on the top of the
      * heap with an immediate timeout so it will be processed now.
      */
@@ -779,7 +872,7 @@ sel_stop_timer_with_done(sel_timer_t *timer,
 
  out_unlock:
     sel_timer_unlock(sel);
-    return 0;
+    return rv;
 }
 
 void
@@ -945,7 +1038,8 @@ process_runners(struct selector_s *sel)
 }
 
 static void
-handle_selector_call(struct selector_s *sel, int i, volatile fd_set *fdset,
+handle_selector_call(struct selector_s *sel, fd_control_t *fdc,
+		     volatile fd_set *fdset, int enabled,
 		     sel_fd_handler_t handler)
 {
     void             *data;
@@ -954,25 +1048,26 @@ handle_selector_call(struct selector_s *sel, int i, volatile fd_set *fdset,
     if (handler == NULL) {
 	/* Somehow we don't have a handler for this.
 	   Just shut it down. */
-	FD_CLR(i, fdset);
+	if (fdset)
+	    FD_CLR(fdc->fd, fdset);
 	return;
     }
 
-    if (!FD_ISSET(i, fdset))
+    if (!enabled)
 	/* The value was cleared, ignore it. */
 	return;
 
-    data = sel->fds[i].data;
-    state = sel->fds[i].state;
+    data = fdc->data;
+    state = fdc->state;
     state->use_count++;
     sel_fd_unlock(sel);
-    handler(i, data);
+    handler(fdc->fd, data);
     sel_fd_lock(sel);
     state->use_count--;
     if (state->deleted && state->use_count == 0) {
 	if (state->done) {
 	    sel_fd_unlock(sel);
-	    state->done(i, data);
+	    state->done(fdc->fd, data);
 	    sel_fd_lock(sel);
 	}
 	free(state);
@@ -1013,6 +1108,7 @@ process_fds(struct selector_s	    *sel,
     struct timespec ts = { .tv_sec = timeout->tv_sec,
 			   .tv_nsec = timeout->tv_usec * 1000 };
     unsigned long entry_fd_del_count = sel->fd_del_count;
+    fd_control_t *fdc;
 
     setup_my_sigmask(&sigmask, isigmask);
  retry:
@@ -1043,15 +1139,21 @@ process_fds(struct selector_s	    *sel,
 	   may be from the old fd wakeup. */
 	goto out_unlock;
     for (i = 0; i <= sel->maxfd; i++) {
-	if (FD_ISSET(i, &tmp_read_set))
-	    handle_selector_call(sel, i, &sel->read_set,
-				 sel->fds[i].handle_read);
-	if (FD_ISSET(i, &tmp_write_set))
-	    handle_selector_call(sel, i, &sel->write_set,
-				 sel->fds[i].handle_write);
-	if (FD_ISSET(i, &tmp_except_set))
-	    handle_selector_call(sel, i, &sel->except_set,
-				 sel->fds[i].handle_except);
+	if (FD_ISSET(i, &tmp_read_set)) {
+	    valid_fd(sel, i, &fdc);
+	    handle_selector_call(sel, fdc, &sel->read_set, fdc->read_enabled,
+				 fdc->handle_read);
+	}
+	if (FD_ISSET(i, &tmp_write_set)) {
+	    valid_fd(sel, i, &fdc);
+	    handle_selector_call(sel, fdc, &sel->write_set, fdc->write_enabled,
+				 fdc->handle_write);
+	}
+	if (FD_ISSET(i, &tmp_except_set)) {
+	    valid_fd(sel, i, &fdc);
+	    handle_selector_call(sel, fdc, &sel->except_set,
+				 fdc->except_enabled, fdc->handle_except);
+	}
     }
  out_unlock:
     sel_fd_unlock(sel);
@@ -1064,7 +1166,7 @@ static int
 process_fds_epoll(struct selector_s *sel, struct timeval *tvtimeout,
 		  sigset_t *isigmask)
 {
-    int rv, fd;
+    int rv;
     struct epoll_event event;
     int timeout;
     sigset_t sigmask;
@@ -1088,8 +1190,7 @@ process_fds_epoll(struct selector_s *sel, struct timeval *tvtimeout,
 	return rv;
 
     sel_fd_lock(sel);
-    fd = event.data.fd;
-    fdc = (fd_control_t *) &sel->fds[fd];
+    valid_fd(sel, event.data.fd, &fdc);
     if (entry_fd_del_count != sel->fd_del_count)
 	/* Something was deleted from the FD set, don't process this as it
 	   may be from the old fd wakeup. */
@@ -1105,7 +1206,7 @@ process_fds_epoll(struct selector_s *sel, struct timeval *tvtimeout,
 	 * EPOLLHUP or EPOLLERR, anyway, and then doing the callback
 	 * by hand.
 	 */
-	sel_update_fd(sel, fd, EPOLL_CTL_DEL);
+	sel_update_fd(sel, fdc, EPOLL_CTL_DEL);
 	fdc->saved_events = event.events & (EPOLLHUP | EPOLLERR);
 	/*
 	 * Have it handle read data, too, so if there is a pending
@@ -1114,16 +1215,19 @@ process_fds_epoll(struct selector_s *sel, struct timeval *tvtimeout,
 	event.events |= EPOLLIN;
     }
     if (event.events & (EPOLLIN | EPOLLHUP))
-	handle_selector_call(sel, fd, &sel->read_set, fdc->handle_read);
+	handle_selector_call(sel, fdc, NULL, fdc->read_enabled,
+			     fdc->handle_read);
     if (event.events & EPOLLOUT)
-	handle_selector_call(sel, fd, &sel->write_set, fdc->handle_write);
+	handle_selector_call(sel, fdc, NULL, fdc->write_enabled,
+			     fdc->handle_write);
     if (event.events & (EPOLLPRI | EPOLLERR))
-	handle_selector_call(sel, fd, &sel->except_set, fdc->handle_except);
+	handle_selector_call(sel, fdc, NULL, fdc->except_enabled,
+			     fdc->handle_except);
 
  rearm:
     /* Rearm the event.  Remember it could have been deleted in the handler. */
     if (fdc->state)
-	sel_update_fd(sel, fd, EPOLL_CTL_MOD);
+	sel_update_fd(sel, fdc, EPOLL_CTL_MOD);
     sel_fd_unlock(sel);
 
     return rv;
@@ -1148,9 +1252,9 @@ sel_setup_forked_process(struct selector_s *sel)
     }
 
     for (i = 0; i <= sel->maxfd; i++) {
-	volatile fd_control_t *fdc = &sel->fds[i];
-	if (fdc->state)
-	    sel_update_fd(sel, i, EPOLL_CTL_ADD);
+	fd_control_t *fdc = sel->fds[i];
+	if (fdc && fdc->state)
+	    sel_update_fd(sel, fdc, EPOLL_CTL_ADD);
     }
     return 0;
 }
@@ -1293,7 +1397,6 @@ sel_alloc_selector_thread(struct selector_s **new_selector, int wake_sig,
 			  void *cb_data)
 {
     struct selector_s *sel;
-    unsigned int i;
     int rv;
     sigset_t sigset;
 
@@ -1317,9 +1420,7 @@ sel_alloc_selector_thread(struct selector_s **new_selector, int wake_sig,
     FD_ZERO((fd_set *) &sel->write_set);
     FD_ZERO((fd_set *) &sel->except_set);
 
-    for (i=0; i<FD_SETSIZE; i++) {
-	init_fd((fd_control_t *) &(sel->fds[i]));
-    }
+    memset(sel->fds, 0, sizeof(sel->fds));
 
     theap_init(&sel->timer_heap);
 
@@ -1372,6 +1473,7 @@ int
 sel_free_selector(struct selector_s *sel)
 {
     sel_timer_t *elem;
+    unsigned int i;
 
     elem = theap_get_top(&(sel->timer_heap));
     while (elem) {
@@ -1383,6 +1485,16 @@ sel_free_selector(struct selector_s *sel)
     if (sel->epollfd >= 0)
 	close(sel->epollfd);
 #endif
+    for (i = 0; i < FD_SETSIZE; i++) {
+	while (sel->fds[i]) {
+	    fd_control_t *fdc = sel->fds[i];
+
+	    sel->fds[i] = fdc->next;
+	    if (fdc->state)
+		free(fdc->state);
+	    free(fdc);
+	}
+    }
     if (sel->fd_lock)
 	sel->sel_lock_free(sel->fd_lock);
     if (sel->timer_lock)
