@@ -66,6 +66,7 @@
 #include <OpenIPMI/internal/ipmi_malloc.h>
 #include <OpenIPMI/internal/ilist.h>
 
+IPMI_UTILS_DLL_PUBLIC
 void (*ipmi_malloc_log)(enum ipmi_log_type_e log_type, const char *format, ...)
 #if __GNUC__ > 2
      __attribute__ ((__format__ (__printf__, 2, 3)))
@@ -80,9 +81,9 @@ void (*ipmi_malloc_log)(enum ipmi_log_type_e log_type, const char *format, ...)
 #define FREE_SIGNATURE 0xb981cef1
 #define BYTE_SIGNATURE 0x74
 
-int __ipmi_debug_malloc = 0;
+int i__ipmi_debug_malloc = 0;
 
-os_handler_t *malloc_os_hnd;
+static os_handler_t *malloc_os_hnd = NULL;
 
 struct dbg_malloc_header
 {
@@ -472,3 +473,9 @@ ipmi_malloc_init(os_handler_t *os_hnd)
 	malloc_os_hnd = os_hnd;
     return 0;
 }
+
+void
+ipmi_malloc_shutdown(void)
+{
+    malloc_os_hnd = NULL;
+}
